"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.streamAPI = void 0;
const axios_1 = __importDefault(require("axios"));
const https_proxy_agent_1 = require("https-proxy-agent");
const ws_1 = require("ws");
class streamAPI extends ws_1.EventEmitter {
    /**
     * Client Class
     * @param pageID should be the trakteer page id (NOT Username). check pageID in https://trakteer.id/manage/my-page/settings
     * @param streamKey should be `trstream-xxx`. check key in https://trakteer.id/manage/stream-settings
     */
    constructor(pageID, streamKey, proxy, userAgent) {
        super();
        this.isConnected = false;
        this.messages = [];
        this.username = pageID;
        this.streamKey = streamKey;
        this.agent = !!proxy ? new https_proxy_agent_1.HttpsProxyAgent(proxy) : undefined;
        this.client = new ws_1.WebSocket("wss://socket.trakteer.id/app/2ae25d102cc6cd41100a?protocol=7&client=js&version=5.1.1&flash=false", {
            agent: this.agent,
            headers: {
                "User-Agent": userAgent !== null && userAgent !== void 0 ? userAgent : "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36",
            },
        });
        this.client.once("open", () => {
            axios_1.default
                .get(`https://trakteer.id/${this.username}/stream?key=${this.streamKey}`, {
                httpsAgent: this.agent,
            })
                .then((data) => {
                const userid = data.data;
                const result = /creator-stream\.(.*?)\./gi.exec(userid);
                if (!data.data || !result || !result[1])
                    throw new Error("Failed to read userId data! Invalid key/username?");
                else
                    this.userId = result[1];
                //Subscribe ke Streaming agar mendapatkan feedback
                this.client.send(JSON.stringify({
                    event: "pusher:subscribe",
                    data: {
                        auth: "",
                        channel: `creator-stream.${this.userId}.${this.streamKey}`,
                    },
                }));
                // Kirim ping agar tidak di disconnect
                this.pingInterval = setInterval(() => {
                    this.client.send(JSON.stringify({
                        data: {},
                        event: "pusher:ping",
                    }));
                }, 5000);
                //Subscribe ke Streaming test agar mendapatkan feedback
                this.client.send(JSON.stringify({
                    event: "pusher:subscribe",
                    data: {
                        auth: "",
                        channel: `creator-stream-test.${this.userId}.${this.streamKey}`,
                    },
                }));
                this.isConnected = true;
                this.emit("connect", new Date());
            });
        });
        this.client.on("message", (message) => {
            const msg = JSON.parse(message.toString());
            if (msg.event ===
                "Illuminate\\Notifications\\Events\\BroadcastNotificationCreated") {
                const msgdata = JSON.parse(msg.data);
                msgdata.price_number = parseInt(msgdata.price.replace(/[^\d\,]/gm, "").replace(",", "."));
                this.emit("donation", msgdata);
            }
        });
        this.client.once("close", (code, reason) => {
            this.isConnected = false;
            this.emit("disconnect", new Date());
        });
    }
    /**
     * Get Donation Leaderboard
     * @param dayInterval Get Donation from last x day
     * @param maxAmount Max Amount of leadedrboard
     * @param sortBy Sort By Rupiah amount or Unit Amount
     * @returns Leaderboard
     */
    getLeaderboard() {
        return __awaiter(this, arguments, void 0, function* (dayInterval = 7, maxAmount = 10, sortBy = "unit") {
            const data = (yield axios_1.default.get(`https://api.trakteer.id/v2/stream/${this.streamKey}/top-supporters?interval=${dayInterval}&count=${maxAmount}&sortby=${sortBy}`, {
                httpsAgent: this.agent,
            })).data;
            data.unitIcon = /"(.+?)"/gm.exec(data.unitIcon)[1];
            data.supporter = data.supporter.map((x) => {
                x.sum = parseInt(x.sum);
                return x;
            });
            return data;
        });
    }
    /**
     * Get Supporter from all time
     * @param amount Amount of supporter to get
     * @returns supporter list
     */
    getSupporter() {
        return __awaiter(this, arguments, void 0, function* (amount = 10) {
            const data = (yield axios_1.default.get(`https://api.trakteer.id/v2/stream/${this.streamKey}/latest-tips?limit=${amount}`, {
                httpsAgent: this.agent,
            })).data.latestTip;
            return data;
        });
    }
    /**
     * Get Goal
     * @returns Goal
     */
    getGoal() {
        return __awaiter(this, void 0, void 0, function* () {
            const data = (yield axios_1.default.get(`https://api.trakteer.id/v2/stream/${this.streamKey}/target-data`, {
                httpsAgent: this.agent,
            })).data;
            let [currentGoal, targetGoal] = data.targetValue
                .replace(/\./g, "")
                .split("/")
                .map((x) => parseFloat(x.replace("Rp ", "")));
            // A bit long, lul. short this please loll
            // 'Rp 0 / Rp 75.000' <~ This should be the original text.
            return {
                target: {
                    current: currentGoal,
                    target: targetGoal,
                    progress: parseInt(data.targetProgress),
                },
                title: data.targetTitle,
                url: data.pageUrl,
            };
        });
    }
}
exports.streamAPI = streamAPI;
