"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../src");
const bun_test_1 = require("bun:test");
const events_1 = require("events");
if (!process.env.PAGEID || !process.env.STREAM_APIKEY)
    throw new Error("PAGEID or STREAM_APIKEY is not defined");
const client = new src_1.streamAPI(process.env.PAGEID, process.env.STREAM_APIKEY); //Cek page id di : https://trakteer.id/manage/my-page/settings
(0, bun_test_1.describe)("should connect to stream", () => __awaiter(void 0, void 0, void 0, function* () {
    (0, bun_test_1.test)("should connect", () => {
        client.once("connect", (ts) => {
            (0, bun_test_1.expect)(client.isConnected).toBeTrue();
            (0, bun_test_1.expect)(ts).toBeDate();
        });
    });
    (0, bun_test_1.test)("Should fire on donation", () => __awaiter(void 0, void 0, void 0, function* () {
        const [donation] = (yield (0, events_1.once)(client, "donation"));
        (0, bun_test_1.expect)(donation).toBeObject();
        (0, bun_test_1.expect)(donation).toContainKeys([
            "id",
            "media",
            "price",
            "price_number",
            "quantity",
            "supporter_avatar",
            "supporter_message",
            "supporter_name",
            "type",
            "unit",
            "unit_icon",
        ]);
        (0, bun_test_1.expect)(donation.price_number).toBeNumber();
    }));
    (0, bun_test_1.test)("Get the leaderboard", () => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield client.getLeaderboard();
        (0, bun_test_1.expect)(res).toBeObject();
        (0, bun_test_1.expect)(res.pageUrl).toBeString();
        (0, bun_test_1.expect)(res.supporter).toBeArray();
        (0, bun_test_1.expect)(res.unitIcon).toBeString();
        (0, bun_test_1.expect)(res.unitName).toBeString();
    }));
    (0, bun_test_1.test)("Get Goal Information", () => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield client.getGoal();
        (0, bun_test_1.expect)(res.target).toBeObject();
        (0, bun_test_1.expect)(res.target.current).toBeNumber();
        (0, bun_test_1.expect)(res.target.progress).toBeNumber();
        (0, bun_test_1.expect)(res.title).toBeString();
        (0, bun_test_1.expect)(res.url).toBeString();
    }));
    (0, bun_test_1.test)("Get Supporter", () => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield client.getSupporter();
        (0, bun_test_1.expect)(res).toBeArray();
        if (res[0]) {
            (0, bun_test_1.expect)(res[0]).toBeObject();
            (0, bun_test_1.expect)(res[0].display_name).toBeString();
            (0, bun_test_1.expect)(res[0].support_message).toBeString();
            (0, bun_test_1.expect)(res[0].quantity).toBeNumber();
        }
    }));
}));
client.getSupporter(2).then((result) => {
    console.log(result);
    /*
          [
              {
                  display_name: 'Name #1',
                  support_message: 'Hello!!',
                  quantity: 12
              },
              {
                  display_name: 'Name #2',
                  support_message: 'Sup!',
                  quantity: 10
              }
          ]
      */
});
